@@ -4,7 +4,6 @@
 
 from __future__ import unicode_literals, absolute_import
 
-from fs import mountfs
 import os
 import socket
 
@@ -36,12 +35,6 @@ def get_absolute_path(path, base=''):
     return os.path.abspath(path)
 
 
-def rebase_fs(base, filesystem):
-    mounted_fs = mountfs.MountFS()
-    mounted_fs.mount(base, filesystem)
-    return mounted_fs
-
-
 def get_relative_path(root, path, base=''):
     """Converts the given 'path' to a path relative to the 'root'."""
     return os.path.relpath(get_absolute_path(path, base=base), root)
